wsipipe.load.annotations package
================================

.. automodule:: wsipipe.load.annotations
   :members:
   :undoc-members:
   :show-inheritance:

annotation module
------------------------------------------

.. automodule:: wsipipe.load.annotations.annotation
   :members:
   :undoc-members:
   :show-inheritance:

asapxml module
---------------------------------------

.. automodule:: wsipipe.load.annotations.asapxml
   :members:
   :undoc-members:
   :show-inheritance:

